@@ -1,6 +1,7 @@
 ## Imports
 # Libraries
 from __future__ import annotations
+import re
 from typing import Union, Iterator
 import os
 import time
@@ -62,6 +63,24 @@ class FlowFingerprint:
     }
 
 
+    @staticmethod
+    def slugify(name: str) -> str:
+        """
+        Slugify a given name (e.g. a host address),
+        by replacing unsupported characters with dashes.
+
+        Args:
+            name (str): Name to slugify.
+        Returns:
+            str: Slugified name.
+        """
+        pattern = r"[^a-zA-Z0-9_.-]"
+        special_chars = re.findall(pattern, name)
+        for char in special_chars:
+            name = name.replace(char, "-")
+        return name
+
+
     @staticmethod
     def from_policy(policy: dict) -> FlowFingerprint:
         """
@@ -316,9 +335,29 @@ class FlowFingerprint:
         return different_hosts
     
 
+    def contains_port(self, port: int) -> bool:
+        """
+        Check if this FlowFingerprint object contains the given port.
+
+        Args:
+            port (int): Port number to check.
+        Returns:
+            bool: True if the FlowFingerprint contains the port, False otherwise.
+        Raises:
+            TypeError: If the port is not an integer.
+        """
+        if not isinstance(port, int):
+            raise TypeError(f"Port must be an integer, got {type(port)}")
+
+        for _, p in self.get_fixed_ports():
+            if p == port:
+                return True
+        return False
+    
+
     def match_ports(self, other: FlowFingerprint, match_random_ports: bool = False) -> bool:
         """
-        Check if the ports of given FlowFingerprint object,
+        Check if the ports of the given FlowFingerprint object,
         match the ports of this FlowFingerprint object.
 
         Args:
@@ -555,7 +594,12 @@ class FlowFingerprint:
         Returns:
             str: Identifier for this FlowFingerprint.
         """
-        id = f"{self.src}-{self.dst}_{self.transport_protocol}"
+        # Slugify host's addresses
+        src = FlowFingerprint.slugify(self.src)
+        dst = FlowFingerprint.slugify(self.dst)
+
+        # Initialize identifier
+        id = f"{src}-{dst}_{self.transport_protocol}"
         fixed_ports = self.get_fixed_ports()
 
         # Hosts & ports
